<?php
namespace Postmatic\Premium\Actions;

use Postmatic\Premium\Repositories\Digest_List as Digest_List_Repo;
use Postmatic\Commentium\Repositories\Scheduled_Callback_HTTP as Scheduled_Callback_HTTP_Repo;

/**
 * Take action based on core options tab events.
 * @since 0.1.0
 */
class Option {

	/**
	 * When core options are updated, perform any necessary related adjustments like removing digest callbacks.
	 * @since 2.0.0
	 * @param array $old_value
	 * @param array $new_value
	 * @param string $key
	 * @param Digest_List_Repo|null $list_repo
	 * @param Scheduled_Callback_HTTP_Repo|null $callback_repo
	 */
	public static function update(
		$old_value,
		$new_value,
		$key = '',
		Digest_List_Repo $list_repo = null,
		Scheduled_Callback_HTTP_Repo $callback_repo = null
	) {

		if ( ! \Prompt_Core::$options or $key != \Prompt_Core::$options->get_key() ) {
			return;
		}

		if ( $old_value == $new_value ) {
			return;
		}

		if ( ! array_key_exists( 'enable_digests', $new_value ) or ! array_key_exists( 'enable_digests', $old_value ) ) {
			return;
		}

		if ( $new_value['enable_digests'] or ! $old_value['enable_digests'] ) {
			return;
		}

		self::disabled_digests( $list_repo, $callback_repo );
	}

	/**
	 * When digests are disabled, delete all digest scheduled callbacks.
	 *
	 * @since 0.1.0
	 * @param Digest_List_Repo $list_repo Optional digest list repository
	 * @param Scheduled_Callback_HTTP_Repo $callback_repo Optional callback repository
	 */
	protected static function disabled_digests(
		Digest_List_Repo $list_repo = null,
		Scheduled_Callback_HTTP_Repo $callback_repo = null
	) {

		$list_repo = $list_repo ?: new Digest_List_Repo();

		$callback_repo = $callback_repo ?: new Scheduled_Callback_HTTP_Repo();

		$lists = $list_repo->all();

		foreach( $lists as $list ) {
			if ( $list->get_callback_id() ) {
				$callback_repo->delete( $list->get_callback_id() );
				$list->set_callback_id( null );
				$list_repo->save( $list );
			}
		}
	}
}